import * as prompts from "@clack/prompts";
import { doesRepositoryExist } from "../doesRepositoryExist.js";
import { isUsingCreateEngine } from "../isUsingCreateEngine.js";
import { filterPromptCancel } from "../prompts.js";
import { createRepositoryWithApi } from "./createRepositoryWithApi.js";
async function ensureRepositoryExists(octokit, options) {
  let { repository } = options;
  let createRepository = options.mode === "create";
  while (octokit) {
    if (isUsingCreateEngine() || await doesRepositoryExist(octokit, options)) {
      return { octokit, repository };
    }
    const selection = createRepository ? "create" : filterPromptCancel(
      await prompts.select({
        message: `Repository ${options.repository} doesn't seem to exist under ${options.owner}. What would you like to do?`,
        options: [
          { label: "Create a new repository", value: "create" },
          {
            label: "Switch to a different repository name",
            value: "different"
          },
          {
            label: "Keep changes local",
            value: "local"
          },
          { label: "Bail out and maybe try again later", value: "bail" }
        ]
      })
    );
    createRepository = false;
    switch (selection) {
      case "bail":
      case void 0:
        return {};
      case "create":
        await createRepositoryWithApi(octokit, {
          owner: options.owner,
          preserveGeneratedFrom: options.preserveGeneratedFrom,
          repository
        });
        return { octokit, repository };
      case "different": {
        const newRepository = filterPromptCancel(
          await prompts.text({
            message: `What would you like to call the repository?`
          })
        );
        if (!newRepository) {
          return {};
        }
        repository = newRepository;
        break;
      }
      case "local":
        octokit = void 0;
        break;
    }
  }
  return { octokit, repository };
}
export {
  ensureRepositoryExists
};
//# sourceMappingURL=ensureRepositoryExists.js.map